PromotionBoxStyle class

Constructors

PromotionBoxStyle({required Color? borderColor, required Color? badgeShadowColor, required Color? badgeColor, required Color? badgeBorderColor, required TextStyle? badgeTextStyle, required List<Color>? gradientColors, required double? textureOpacity})
const
PromotionBoxStyle.$default({required SBBBaseStyle baseStyle})
factory

Properties

badgeBorderColor Color?
final
badgeColor Color?
final
badgeShadowColor Color?
final
badgeTextStyle TextStyle?
final
borderColor Color?
final
gradientColors List<Color>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textureOpacity double?
final

Methods

copyWith({Color? borderColor, Color? badgeShadowColor, Color? badgeColor, Color? badgeBorderColor, TextStyle? badgeTextStyle, List<Color>? gradientColors, double? textureOpacity}) PromotionBoxStyle
merge(PromotionBoxStyle? other) PromotionBoxStyle
The given other null properties its null properties are replaced with the non-null properties of this text style. Another way to think of it is that the "missing" properties of the other style are filled by the properties of this style.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

darkGradient List<Color>
getter/setter pair
lightGradient List<Color>
getter/setter pair

Static Methods

lerp(PromotionBoxStyle? $this, PromotionBoxStyle? other, double t) PromotionBoxStyle