SBBTimePicker class
SBB Time Picker. Use according to documentation.
See also:
- SBBPicker, variant for custom values.
- SBBDatePicker, variant for date values.
- SBBDateTimePicker, variant for date time values.
- digital.sbb.ch/en/design-system/mobile/components/picker/
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SBBTimePicker
Constructors
-
SBBTimePicker({Key? key, required ValueChanged<
TimeOfDay> ? onTimeChanged, TimeOfDay? initialTime, TimeOfDay? minimumTime, TimeOfDay? maximumTime, int minuteInterval = _defaultMinuteInterval}) - Constructs an SBBDateTimePicker.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialTime → TimeOfDay
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maximumTime → TimeOfDay?
-
final
- minimumTime → TimeOfDay?
-
final
- minuteInterval → int
-
final
-
onTimeChanged
→ ValueChanged<
TimeOfDay> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SBBTimePicker> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
showModal(
{required BuildContext context, String? title, TimeOfDay? initialTime, TimeOfDay? minimumTime, TimeOfDay? maximumTime, int minuteInterval = _defaultMinuteInterval, ValueChanged< TimeOfDay> ? onTimeChanged}) → void - Shows an SBBModalSheet with an SBBTimePicker to select a TimeOfDay. Use according to documentation.