SelectMenuItem<T> class
An item in a menu created by a SBBSelect or SBBMultiSelect.
The type T is the type of the value the entry represents. All the entries
in a given menu must represent values with consistent types.
Constructors
- SelectMenuItem({required T value, required String label})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited