SBBSegmentedButton class
The SBB Segmented-Button. Use according to documentation.
See also:
- SBBRadioListItem and SBBRadio, a widget with semantics similar to SBBSegmentedButton.
- SBBSlider, for selecting a value in a range.
- SBBCheckboxListItem, SBBCheckbox and SBBSwitch, for toggling a particular value on or off.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SBBSegmentedButton
Constructors
-
SBBSegmentedButton({Key? key, required List<
String> values, required int selectedStateIndex, required ValueChanged<int> selectedIndexChanged}) -
SBBSegmentedButton.custom({Key? key, required List<
SegmentedButtonWidgetBuilder> widgetBuilders, required int selectedStateIndex, required ValueChanged<int> selectedIndexChanged, SBBControlStyleSelector<SBBSegmentedButtonStyle> ? styleSelector}) -
const
-
SBBSegmentedButton.icon({Key? key, required Map<
IconData, String> icons, required int selectedStateIndex, required ValueChanged<int> selectedIndexChanged, bool withText = false}) -
SBBSegmentedButton.iconCustom({Key? key, required Map<
IconData, String> icons, required int selectedStateIndex, required ValueChanged<int> selectedIndexChanged, bool withText = false, SBBControlStyleSelector<SBBSegmentedButtonStyle> ? styleSelector}) -
SBBSegmentedButton.redIcon({Key? key, required Map<
IconData, String> icons, required int selectedStateIndex, required ValueChanged<int> selectedIndexChanged, bool withText = false}) -
SBBSegmentedButton.redText({Key? key, required List<
String> values, required int selectedStateIndex, required ValueChanged<int> selectedIndexChanged}) -
SBBSegmentedButton.text({Key? key, required List<
String> values, required int selectedStateIndex, required ValueChanged<int> selectedIndexChanged}) -
SBBSegmentedButton.textCustom({Key? key, required List<
String> values, required int selectedStateIndex, required ValueChanged<int> selectedIndexChanged, SBBControlStyleSelector<SBBSegmentedButtonStyle> ? styleSelector})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedIndexChanged
→ ValueChanged<
int> -
final
- selectedStateIndex → int
-
final
-
styleSelector
→ SBBControlStyleSelector<
SBBSegmentedButtonStyle> ? -
final
-
widgetBuilders
→ List<
SegmentedButtonWidgetBuilder> -
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → SegmentedButtonState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited